"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OnNavigationEventGenerator = void 0;
const detect_url_change_1 = require("../../../lib/detect-url-change");
const factories_1 = require("../../../types/factories");
function getChangedProperties(url1, url2) {
    const changed = [];
    const propertiesToCompare = ['pathname', 'search', 'hash'];
    for (const property of propertiesToCompare) {
        if (url1[property] !== url2[property]) {
            if (property === 'pathname') {
                changed.push('path');
            }
            else {
                changed.push(property);
            }
        }
    }
    return changed;
}
class OnNavigationEventGenerator {
    constructor() {
        this.id = 'navigation';
        this.urlChange = new detect_url_change_1.URLChangeObservable();
    }
    register(emitter) {
        // emit navigation signal on page load
        emitter.emit((0, factories_1.createNavigationSignal)({
            action: 'pageLoad',
            ...this.createCommonFields(),
        }));
        // emit a navigation signal whenever the URL has changed
        this.urlChange.subscribe(({ previous, current }) => emitter.emit((0, factories_1.createNavigationSignal)({
            action: 'urlChange',
            prevUrl: previous.href,
            changedProperties: getChangedProperties(current, previous),
            ...this.createCommonFields(),
        })));
        return () => {
            this.urlChange.unsubscribe();
        };
    }
    createCommonFields() {
        return {
            // these fields are named after those from the page call, rather than a DOM api.
            url: location.href,
            path: location.pathname,
            hash: location.hash,
            search: location.search,
            title: document.title,
        };
    }
}
exports.OnNavigationEventGenerator = OnNavigationEventGenerator;
//# sourceMappingURL=navigation-gen.js.map