"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerGenerator = void 0;
const logger_1 = require("../../lib/logger");
const is_class_1 = require("../../utils/is-class");
const registerGenerator = async (emitter, signalGenerators, settings) => {
    const _register = (gen) => {
        logger_1.logger.debug('Registering generator:', gen.id || gen.name);
        if ((0, is_class_1.isClass)(gen)) {
            // Check if Gen is a function and has a constructor
            return new gen(settings).register(emitter);
        }
        else {
            return gen.register(emitter);
        }
    };
    const cleanupFns = await Promise.all(signalGenerators.map(_register));
    // Return a cleanup function that calls all the cleanup functions (e.g unsubscribes from event listeners)
    return () => cleanupFns.forEach((fn) => fn());
};
exports.registerGenerator = registerGenerator;
//# sourceMappingURL=register.js.map